@@ -50,8 +50,8 @@ downloads, installation and source code.
 
 __Conventions__  = 'CF-1.5'
 __author__       = 'David Hassell'
-__date__         = '09 February 2016'
-__version__      = '1.1.4'
+__date__         = '2016-03-03'
+__version__      = '1.1.5'
 
 from distutils.version import StrictVersion
 import imp
@@ -65,19 +65,19 @@ if not (StrictVersion('2.6.0')
         "Bad python version: cf requires 2.6 <= python < 3.0. Got %s" %
         platform.python_version())
 
-# Check the version of numpy
-import numpy
-if StrictVersion(numpy.__version__) < StrictVersion('1.7'):
-    raise ImportError(
-        "Bad numpy version: cf %s requires numpy >= 1.7. Got %s" %
-        (__version__, numpy.__version__))
-
-# Check the version of netCDF4
-import netCDF4
-if StrictVersion(netCDF4.__version__) < StrictVersion('0.9.7'):
-    raise ImportError(
-        "Bad netCDF4 version: cf %s requires netCDF4 >= 0.9.7. Got %s" %
-        (__version__, netCDF4.__version__))
+## Check the version of numpy
+#import numpy
+#if StrictVersion(numpy.__version__) < StrictVersion('1.7'):
+#    raise ImportError(
+#        "Bad numpy version: cf %s requires numpy >= 1.7. Got %s" %
+#        (__version__, numpy.__version__))
+#
+## Check the version of netCDF4
+#import netCDF4
+#if StrictVersion(netCDF4.__version__) < StrictVersion('0.9.7'):
+#    raise ImportError(
+#        "Bad netCDF4 version: cf %s requires netCDF4 >= 0.9.7. Got %s" %
+#        (__version__, netCDF4.__version__))
 
 try:
     imp.find_module('ESMF')
