@@ -385,21 +385,16 @@ is for the respective CF axis type, otherwise None.
 
 :Examples:
 
->>> c.standard_name
-'longitude'
+>>> c.X
+True
 >>> c.ctype
 'X'
 
->>> c.units
-'days since 2005-12-1'
+>>> c.T
+True
 >>> c.ctype
 'T'
 
->>> c.units
-'kelvin'
->>> print c.ctype
-None
-
 '''
         for t in ('T', 'X', 'Y', 'Z'):
             if getattr(self, t):
@@ -580,17 +575,18 @@ extensions to the numpy indexing functionality:
     # ----------------------------------------------------------------
     @property
     def T(self):
-        '''
+        '''True if and only if the coordinates are for a CF T axis.
 
-True if and only if the coordinate is a CF T axis coordinate.
+CF T axis coordinates are for a reference time axis hhave one or more
+of the following:
+
+  * The `axis` property has the value ``'T'``
+  * Units of reference time (see `cf.Units.isreftime` for details)
+  * The `standard_name` property is one of ``'time'`` or
+    ``'forecast_reference_time'longitude'``
 
 .. seealso:: `ctype`, `X`, `~cf.Coordinate.Y`, `Z`
 
-:Returns:
-
-    out : bool
-        Whether or not the coordinate is a T axis coordinate.
-
 :Examples:
 
 >>> c.Units
@@ -603,12 +599,10 @@ True
 >>> c.T
 True
 
->>> c.axis
-'T'
->>> c.T
+>>> c.axis == 'T' and c.T
 True
 
-'''      
+        '''      
         if self.ndim > 1:
             return self.getprop('axis', None) == 'T'
 
@@ -704,17 +698,18 @@ array([5, 3, 1])
     # ----------------------------------------------------------------
     @property
     def X(self):
-        '''
+        '''True if and only if the coordinates are for a CF X axis.
 
-True if and only if the coordinate is a CF X axis coordinate.
+CF X axis coordinates are for a horizontal axis have one or more of
+the following:
+
+  * The `axis` property has the value ``'X'``
+  * Units of longitude (see `cf.Units.islongitude` for details)
+  * The `standard_name` property is one of ``'longitude'``,
+    ``'projection_x_coordinate'`` or ``'grid_longitude'``
 
 .. seealso:: `ctype`, `T`, `~cf.Coordinate.Y`, `Z`
 
-:Returns:
-
-    out : bool
-        Whether or not the coordinate is a X axis coordinate.
-
 :Examples:
 
 >>> c.Units
@@ -727,20 +722,18 @@ True
 >>> c.X
 True
 
->>> c.axis
-'X'
->>> c.X
+>>> c.axis == 'X' and c.X
 True
 
-'''              
+        '''              
         if self.ndim > 1:
             return self.getprop('axis', None) == 'X'
 
-        if (self.Units.islongitude or 
-            self.getprop('standard_name', 'X') in ('longitude',
-                                                   'projection_x_coordinate',
-                                                   'grid_longitude') or
-            self.getprop('axis', None) == 'X'):
+        if (self.Units.islongitude or
+            self.getprop('axis', None) == 'X' or
+            self.getprop('standard_name', None) in ('longitude',
+                                                    'projection_x_coordinate',
+                                                    'grid_longitude')):
             return True
         else:
             return False
@@ -751,17 +744,18 @@ True
     # ----------------------------------------------------------------
     @property
     def Y(self):
-        '''
+        '''True if and only if the coordinates are for a CF Y axis.
 
-True if and only if the coordinate is a CF Y axis coordinate.
+CF Y axis coordinates are for a horizontal axis and have one or more
+of the following:
+
+  * The `axis` property has the value ``'Y'``
+  * Units of latitude (see `cf.Units.islatitude` for details)
+  * The `standard_name` property is one of ``'latitude'``,
+    ``'projection_y_coordinate'`` or ``'grid_latitude'``
 
 .. seealso:: `ctype`, `T`, `X`, `Z`
 
-:Returns:
-
-    out : bool
-        Whether or not the coordinate is a Y axis coordinate.
-
 :Examples:
 
 >>> c.Units
@@ -769,8 +763,7 @@ True if and only if the coordinate is a CF Y axis coordinate.
 >>> c.Y
 True
 
->>> c.standard_name in (
-'latitude'
+>>> c.standard_name == 'latitude'
 >>> c.Y
 True
 
@@ -779,15 +772,15 @@ True
 >>> c.Y
 True
 
-'''              
+        '''              
         if self.ndim > 1:
             return self.getprop('axis', None) == 'Y'
 
         if (self.Units.islatitude or 
+            self.getprop('axis', None) == 'Y' or 
             self.getprop('standard_name', 'Y') in ('latitude',
                                                    'projection_y_coordinate',
-                                                   'grid_latitude') or
-            self.getprop('axis', None) == 'Y'):
+                                                   'grid_latitude')):            
             return True
         else:
             return False
@@ -798,17 +791,28 @@ True
     # ----------------------------------------------------------------
     @property
     def Z(self):
-        '''
+        '''True if and only if the coordinates are for a CF Z axis.
 
-True if and only if the coordinate is a CF Z axis coordinate.
+CF Z axis coordinates are for a vertical axis have one or more of the
+following:
+
+  * The `axis` property has the value ``'Z'``
+  * Units of pressure (see `cf.Units.ispressure` for details), level,
+    layer, or sigma_level
+  * The `positive` property has the value ``'up'`` or ``'down'``
+    (case insensitive)
+  * The `standard_name` property is one of
+    ``'atmosphere_ln_pressure_coordinate'``,
+    ``'atmosphere_sigma_coordinate'``,
+    ``'atmosphere_hybrid_sigma_pressure_coordinate'``,
+    ``'atmosphere_hybrid_height_coordinate'``,
+    ``'atmosphere_sleve_coordinate``', ``'ocean_sigma_coordinate'``,
+    ``'ocean_s_coordinate'``, ``'ocean_s_coordinate_g1'``,
+    ``'ocean_s_coordinate_g2'``, ``'ocean_sigma_z_coordinate'`` or
+    ``'ocean_double_sigma_coordinate'``
 
 .. seealso:: `ctype`, `T`, `X`, `~cf.Coordinate.Y`
 
-:Returns:
-
-    out : bool
-        Whether or not the coordinate is a Z axis coordinate.
-
 :Examples:
 
 >>> c.Units
@@ -821,9 +825,7 @@ True
 >>> c.Z
 True
 
->>> c.axis
-'Z'
->>> c.Z
+>>> c.axis == 'Z' and c.Z
 True
 
 >>> c.Units
@@ -836,7 +838,7 @@ True
 >>> c.Z
 True
 
-'''   
+        '''   
         if self.ndim > 1:
             return self.getprop('axis', None) == 'Z'
         
