@@ -40,15 +40,12 @@ _dtype_object = numpy_dtype(object)
 _temporary_files = set()
 
 def _remove_temporary_files(filename=None):
-    '''
-
-Remove temporary partition files from disk.
+    '''Remove temporary partition files from disk.
 
 The removed files' names are deleted from the _temporary_files set.
 
 It is intended to delete individual files as part of the garbage
-collection process and to delete all files when python exits. It is
-not recommended to be as a general tidy-up function.
+collection process and to delete all files when python exits.
 
 This is quite brutal and may break partitions if used unwisely. It is
 not recommended to be used as a general tidy-up function.
@@ -78,19 +75,26 @@ set(['/tmp/cf_array_B8SSw2.npy',
 >>> _temporary_files
 set()
 
-'''
+    '''
     if filename is not None:
         if filename in _temporary_files:
-            # Remove the given temporary file        
+            # Remove the given temporary file
+            try:
+                remove(filename)
+            except OSError:
+                pass
             _temporary_files.remove(filename)
-            remove(filename)
         #--- End: if
         return
     #--- End: if
 
     # Still here? Then remove all temporary files
     for filename in _temporary_files:
-        remove(filename)
+        try:
+            remove(filename)
+        except OSError:
+            pass
+    #--- End: for
 
     _temporary_files.clear()
 #--- End: def
@@ -620,7 +624,7 @@ otherwise a memory leak could occur. For example:
 
 '''
         unique = getrefcount(self.subarray) <= 2
-            
+        
         p_axes   = self.axes
         p_flip   = self.flip
         p_part   = self.part
@@ -726,14 +730,11 @@ otherwise a memory leak could occur. For example:
              inplace = update and unique
         #--- End: if
 
-#        print '____________________'
-#        print repr(p_data), type(p_data), p_units, units, func
         if func is not None:
             p_data  = func(p_data, p_units, units, inplace)
             p_units = units
             copy = False
         #--- End: if
-#        print repr(p_data), type(p_data)
 
         if p_data.size > 1:
             if flip or p_flip:
