@@ -16,9 +16,10 @@ from .netcdf.read import is_netcdf_file
 from .um.read     import read as um_read
 from .um.read     import is_um_file
 
-def read(files, verbose=False, ignore_read_error=False, aggregate=True,
-         umversion=4.5, nfields=None, squeeze=False, unsqueeze=False, fmt=None,
-         select=None, select_options={}, top_level=None):
+def read(files, verbose=False, ignore_read_error=False,
+         aggregate=True, umversion=4.5, nfields=None, squeeze=False,
+         unsqueeze=False, fmt=None, select=None, select_options={},
+         top_level=None, height_at_top_of_model=None):
     '''Read fields from files into `cf.Field` objects.
 
 A file may be on disk or on a OPeNDAP server.
@@ -263,7 +264,8 @@ Any amount of any combination of CF-netCDF, CFA-netCDF and Met Office
                                   aggregate_options=aggregate_options,
                                   umversion=umversion,
                                   selected_fmt=fmt,
-                                  promote=promote)
+                                  promote=promote,
+                                  height_at_top_of_model=height_at_top_of_model)
             
             # --------------------------------------------------------
             # Select matching fields
@@ -364,7 +366,8 @@ def _read_a_file(filename,
                  verbose=False,
                  umversion=None,
                  selected_fmt=None,
-                 promote=()):
+                 promote=(),
+                 height_at_top_of_model=None):
     '''
 
 Read the contents of a single file into a field list.
@@ -421,8 +424,9 @@ Read the contents of a single file into a field list.
                              verbose=verbose)
         
     elif ftype == 'UM' and (selected_fmt in (None, 'PP', 'FF')):
-        fields = um_read(filename, um_version=umversion, verbose=verbose,
-                         set_standard_name=False)
+        fields = um_read(filename, um_version=umversion,
+                         verbose=verbose, set_standard_name=False,
+                         height_at_top_of_model=height_at_top_of_model)
 
         # PP fields are aggregated intrafile prior to interfile
         # aggregation
