@@ -45,7 +45,16 @@ destination grid that can then be used by the run_regridding method.
     method: string, optional
         By default the regridding method is conservative. If this
         parameter is set to 'bilinear' then multilinear interpolation
-        is used.
+        is used. If it is set to 'nearest_stod' then nearest neighbor
+        interpolation is used where each destination point is mapped
+        to the closest source point. A given source point may go to
+        multiple destination points, but no destination point will
+        receive input from more than one source point. If it is set
+        to 'nearest_dtos' then nearest neighbor interpolation is used
+        where each destination point is mapped to the closest source
+        point. A given source point may go to multiple destination
+        points, but no destination point will receive input from more
+        than one source point.
     
         """
         # create a handle to the regridding method
@@ -53,6 +62,10 @@ destination grid that can then be used by the run_regridding method.
             regrid_method = ESMF.RegridMethod.CONSERVE
         elif method == 'bilinear':
             regrid_method = ESMF.RegridMethod.BILINEAR
+        elif method == 'nearest_stod':
+            regrid_method = ESMF.RegridMethod.NEAREST_STOD
+        elif method == 'nearest_dtos':
+            regrid_method = ESMF.RegridMethod.NEAREST_DTOS
         else:
             raise ValueError('Regrid method not recognised.')
         
@@ -142,7 +155,7 @@ grid may have an associated mask.
         
         # If not set as cyclic already, check for cyclicity
         if not cyclic:
-            cyclic = abs(x_bounds.datum(-1) - x_bounds.datum(0)) != Data(360,
+            cyclic = abs(x_bounds.datum(-1) - x_bounds.datum(0)) == Data(360,
                      'degrees')
         x_bounds = x_bounds.array
         
